@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "f95a4ef30ac8085641cb5d334605e4565c08cf0f",
+  "commitId": "b873305c51f54b41a59d1ef1d7bd12806fc19ba2",
   "branchName": "release-client-5.16.x",
-  "buildTime": "2023-10-20 07:57:51 GMT",
-  "buildVersion": "836",
+  "buildTime": "2023-11-16 10:39:57 GMT",
+  "buildVersion": "5.1.915",
   "css": [
     "@zoom/client-calendar/static/css/chunk-vendors.974eca6e.css",
-    "@zoom/client-calendar/static/css/app.f1e850b6.css"
+    "@zoom/client-calendar/static/css/app.53099951.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/chunk-vendors.0ec24b21.js",
-    "@zoom/client-calendar/static/js/app.4d7761b3.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.48bad635.js",
+    "@zoom/client-calendar/static/js/app.011c4d43.js"
   ],
   "key": "@zoom/client-calendar"
 };
